==> atlassian_connect_host-0.4.0.tar.gz: test/hc/hc_host_event_model_test.dart <==
library ac_dart.host_event_model.test;

import 'package:atlassian_connect_host/src/hc/hc_host_event_model.dart';
import 'package:atlassian_connect_host/host_event_model.dart';
import 'package:unittest/unittest.dart';

main() {

  group('[Json]', () {
    final clientKey = "b5218487-76c2-44ac-aad5-f701f6c06dc3";
    final sharedSecret = '1ad6f705-fe0b-4111-9551-7ce5d81d2884';
    final capabilitiesUrl = "https://dev-aholmgren1.hipchat.com/v2/capabilities";
    final baseUrl = 'https://dev-aholmgren1.hipchat.com';
    final productType = 'jira';
    final eventType = 'installed';
    final roomId = 82;
    final groupId = 1;

    final json = {
      "oauthId": clientKey,
      "oauthSecret": sharedSecret,
      "capabilitiesUrl": capabilitiesUrl,
      "roomId": roomId,
      "groupId": groupId
    };

    group('[unmarshalling]', () {
      final installedEvent = new HcInstallationEvent.fromJson(json);
      final registration = installedEvent.hostRegistration;
      hostDetails() => registration.hostDetails;

      test('eventType parses correctly', () {
        expect(installedEvent.eventType, equals(AcHostEventType.installed));
      });

      test('hostRegistration not null', () {
        expect(registration, isNotNull);
      });

      test('sharedSecret parses correctly', () {
        expect(registration.sharedSecret, equals(sharedSecret));
      });

      test('hostDetails not null', () {
        expect(hostDetails(), isNotNull);
      });

      test('clientKey parses correctly', () {
        expect(hostDetails().key, equals(clientKey));
      });

      test('capabilitiesUrl parses correctly', () {
        expect(hostDetails().capabilitiesUrl.toString(), 
            equals(capabilitiesUrl));
      });

      test('baseUrl parses correctly', () {
        expect(hostDetails().baseUrl, equals(Uri.parse(baseUrl)));
      });

      test('productType parses correctly', () {
        expect(hostDetails().productType, equals(ProductType.hipchat));
      });

      test('roomId parses correctly', () {
        expect(hostDetails().roomId, equals(roomId));
      });

      test('groupId parses correctly', () {
        expect(hostDetails().groupId, equals(groupId));
      });
    });
  });
}

==> atlassian_connect_host-0.5.4.tar.gz: test/hc/hc_host_event_model_test.dart <==
library ac_dart.host_event_model.test;

import 'package:atlassian_connect_host/src/hc/hc_host_event_model.dart';
import 'package:atlassian_connect_host/host_event_model.dart';
import 'package:test/test.dart';

main() {
  group('[Json]', () {
    final clientKey = "b5218487-76c2-44ac-aad5-f701f6c06dc3";
    final sharedSecret = '1ad6f705-fe0b-4111-9551-7ce5d81d2884';
    final capabilitiesUrl =
        "https://dev-aholmgren1.hipchat.com/v2/capabilities";
    final baseUrl = 'https://dev-aholmgren1.hipchat.com';
//    final productType = 'jira';
//    final eventType = 'installed';
    final roomId = 82;
    final groupId = 1;

    final json = {
      "oauthId": clientKey,
      "oauthSecret": sharedSecret,
      "capabilitiesUrl": capabilitiesUrl,
      "roomId": roomId,
      "groupId": groupId
    };

    group('[unmarshalling]', () {
      final installedEvent = new HcInstallationEvent.fromJson(json);
      final registration = installedEvent.hostRegistration;
      hostDetails() => registration.hostDetails;

      test('eventType parses correctly', () {
        expect(installedEvent.eventType, equals(AcHostEventType.installed));
      });

      test('hostRegistration not null', () {
        expect(registration, isNotNull);
      });

      test('sharedSecret parses correctly', () {
        expect(registration.sharedSecret, equals(sharedSecret));
      });

      test('hostDetails not null', () {
        expect(hostDetails(), isNotNull);
      });

      test('clientKey parses correctly', () {
        expect(hostDetails().key, equals(clientKey));
      });

      test('capabilitiesUrl parses correctly', () {
        expect(
            hostDetails().capabilitiesUrl.toString(), equals(capabilitiesUrl));
      });

      test('baseUrl parses correctly', () {
        expect(hostDetails().baseUrl, equals(Uri.parse(baseUrl)));
      });

      test('productType parses correctly', () {
        expect(hostDetails().productType, equals(ProductType.hipchat));
      });

      test('roomId parses correctly', () {
        expect(hostDetails().roomId, equals(roomId));
      });

      test('groupId parses correctly', () {
        expect(hostDetails().groupId, equals(groupId));
      });
    });
  });
}
